@@ -1,10 +1,11 @@
 """
-betamax
+betamax.
+
 =======
 
-See http://betamax.rtfd.org/ for documentation.
+See https://betamax.readthedocs.io/ for documentation.
 
-:copyright: (c) 2013 by Ian Cordasco
+:copyright: (c) 2013-2016 by Ian Cordasco
 :license: Apache 2.0, see LICENSE for more details
 
 """
@@ -21,5 +22,5 @@ __author__ = 'Ian Cordasco'
 __copyright__ = 'Copyright 2013-2014 Ian Cordasco'
 __license__ = 'Apache 2.0'
 __title__ = 'betamax'
-__version__ = '0.5.1'
+__version__ = '0.7.1'
 __version_info__ = tuple(int(i) for i in __version__.split('.'))
